"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns an estimate of the monthly cost for DevOps Guru to analyze your AWS resources. For more information, see Estimate your Amazon DevOps Guru costs and Amazon DevOps Guru pricing.

    Args:
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.cost_estimation.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.cost_estimation.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="get_cost_estimation",
        op_kwargs={"NextToken": next_token},
    )


async def start(hub, ctx, resource_collection: Dict, client_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Starts the creation of an estimate of the monthly cost to analyze your AWS resources.

    Args:
        resource_collection(Dict): The collection of AWS resources used to create a monthly DevOps Guru cost estimate.
        client_token(str, optional): The idempotency token used to identify each cost estimate request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.cost_estimation.start(ctx, resource_collection=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.cost_estimation.start resource_collection=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="start_cost_estimation",
        op_kwargs={
            "ResourceCollection": resource_collection,
            "ClientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub, ctx, web_acl_id: str, rule_id: str, time_window: Dict, max_items: int
) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Gets detailed information about a specified number of requests--a sample--that AWS WAF randomly selects from among the first 5,000 requests that your AWS resource received during a time range that you choose. You can specify a sample size of up to 500 requests, and you can specify any time range in the previous three hours.  GetSampledRequests returns a time range, which is usually the time range that you specified. However, if your resource (such as a CloudFront distribution) received 5,000 requests before the specified time range elapsed, GetSampledRequests returns an updated time range. This new time range indicates the actual period during which AWS WAF selected the requests in the sample.

    Args:
        web_acl_id(str): The WebACLId of the WebACL for which you want GetSampledRequests to return a sample of requests.
        rule_id(str):  RuleId is one of three values:   The RuleId of the Rule or the RuleGroupId of the RuleGroup for which you want GetSampledRequests to return a sample of requests.    Default_Action, which causes GetSampledRequests to return a sample of the requests that didn't match any of the rules in the specified WebACL.  .
        time_window(Dict): The start date and time and the end date and time of the range for which you want GetSampledRequests to return a sample of requests. You must specify the times in Coordinated Universal Time (UTC) format. UTC format includes the special designator, Z. For example, "2016-09-27T14:50Z". You can specify any time range in the previous three hours.
        max_items(int): The number of requests that you want AWS WAF to return from among the first 5,000 requests that your AWS resource received during the time range. If your resource received fewer requests than the value of MaxItems, GetSampledRequests returns information about all of them. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.sampled_request.get_all(
                ctx, web_acl_id=value, rule_id=value, time_window=value, max_items=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.sampled_request.get_all web_acl_id=value, rule_id=value, time_window=value, max_items=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf",
        operation="get_sampled_requests",
        op_kwargs={
            "WebAclId": web_acl_id,
            "RuleId": rule_id,
            "TimeWindow": time_window,
            "MaxItems": max_items,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    service_type: str,
    identifier: str,
    group: str,
    group_identifier: str,
    requested_dimensions: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Get the attributes of the specified dimension group for a DB instance or data source. For example, if you specify a SQL ID, GetDimensionKeyDetails retrieves the full text of the dimension db.sql.statement associated with this ID. This operation is useful because GetResourceMetrics and DescribeDimensionKeys don't support retrieval of large SQL statement text.

    Args:
        service_type(str): The AWS service for which Performance Insights returns data. The only valid value is RDS.
        identifier(str): The ID for a data source from which to gather dimension data. This ID must be immutable and unique within an AWS Region. When a DB instance is the data source, specify its DbiResourceId value. For example, specify db-ABCDEFGHIJKLMNOPQRSTU1VW2X. .
        group(str): The name of the dimension group. The only valid value is db.sql. Performance Insights searches the specified group for the dimension group ID.
        group_identifier(str): The ID of the dimension group from which to retrieve dimension details. For dimension group db.sql, the group ID is db.sql.id.
        requested_dimensions(List, optional): A list of dimensions to retrieve the detail data for within the given dimension group. For the dimension group db.sql, specify either the full dimension name db.sql.statement or the short dimension name statement. If you don't specify this parameter, Performance Insights returns all dimension data within the specified dimension group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pi.dimension_key.detail.get_all(
                ctx, service_type=value, identifier=value, group=value, group_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pi.dimension_key.detail.get_all service_type=value, identifier=value, group=value, group_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pi",
        operation="get_dimension_key_details",
        op_kwargs={
            "ServiceType": service_type,
            "Identifier": identifier,
            "Group": group,
            "GroupIdentifier": group_identifier,
            "RequestedDimensions": requested_dimensions,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the current Account resource.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.account.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.account.get
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="apigateway", operation="get_account", op_kwargs={}
    )


async def update(hub, ctx, patch_operations: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Changes information about the current Account resource.

    Args:
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.account.update(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.account.update
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_account",
        op_kwargs={"patchOperations": patch_operations},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, account_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Gets the retention settings for the specified Amazon Chime Enterprise account. For more information about retention settings, see Managing Chat Retention Policies in the Amazon Chime Administration Guide.

    Args:
        account_id(str): The Amazon Chime account ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.retention_setting.get_all(ctx, account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.retention_setting.get_all account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_retention_settings",
        op_kwargs={"AccountId": account_id},
    )


async def put_multiple(hub, ctx, account_id: str, retention_settings: Dict) -> Dict:
    r"""
    **Autogenerated function**

     Puts retention settings for the specified Amazon Chime Enterprise account. We recommend using AWS CloudTrail to monitor usage of this API for your account. For more information, see Logging Amazon Chime API Calls with AWS CloudTrail in the Amazon Chime Administration Guide.  To turn off existing retention settings, remove the number of days from the corresponding RetentionDays field in the RetentionSettings object. For more information about retention settings, see Managing Chat Retention Policies in the Amazon Chime Administration Guide.

    Args:
        account_id(str): The Amazon Chime account ID.
        retention_settings(Dict): The retention settings.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.retention_setting.put_multiple(
                ctx, account_id=value, retention_settings=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.retention_setting.put_multiple account_id=value, retention_settings=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="put_retention_settings",
        op_kwargs={"AccountId": account_id, "RetentionSettings": retention_settings},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    dry_run: bool = None,
    group_name: str = None,
    strategy: str = None,
    partition_count: int = None,
    tag_specifications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a placement group in which to launch instances. The strategy of the placement group determines how the instances are organized within the group.  A cluster placement group is a logical grouping of instances within a single Availability Zone that benefit from low network latency, high network throughput. A spread placement group places instances on distinct hardware. A partition placement group places groups of instances in different partitions, where instances in one partition do not share the same hardware with instances in another partition. For more information, see Placement groups in the Amazon EC2 User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        group_name(str, optional): A name for the placement group. Must be unique within the scope of your account for the Region. Constraints: Up to 255 ASCII characters. Defaults to None.
        strategy(str, optional): The placement strategy. Defaults to None.
        partition_count(int, optional): The number of partitions. Valid only when Strategy is set to partition. Defaults to None.
        tag_specifications(List, optional): The tags to apply to the new placement group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.placement_group.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.placement_group.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_placement_group",
        op_kwargs={
            "DryRun": dry_run,
            "GroupName": group_name,
            "Strategy": strategy,
            "PartitionCount": partition_count,
            "TagSpecifications": tag_specifications,
        },
    )


async def delete(hub, ctx, group_name: str, dry_run: bool = None) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified placement group. You must terminate all instances in the placement group before you can delete the placement group. For more information, see Placement groups in the Amazon EC2 User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        group_name(str): The name of the placement group.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.placement_group.delete(ctx, group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.placement_group.delete group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_placement_group",
        op_kwargs={"DryRun": dry_run, "GroupName": group_name},
    )


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    dry_run: bool = None,
    group_names: List = None,
    group_ids: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified placement groups or all of your placement groups. For more information, see Placement groups in the Amazon EC2 User Guide.

    Args:
        filters(List, optional): The filters.    group-name - The name of the placement group.    state - The state of the placement group (pending | available | deleting | deleted).    strategy - The strategy of the placement group (cluster | spread | partition).    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources that have a tag with a specific key, regardless of the tag value.  . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        group_names(List, optional): The names of the placement groups. Default: Describes all your placement groups, or only those otherwise specified. Defaults to None.
        group_ids(List, optional): The IDs of the placement groups. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.placement_group.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.placement_group.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_placement_groups",
        op_kwargs={
            "Filters": filters,
            "DryRun": dry_run,
            "GroupNames": group_names,
            "GroupIds": group_ids,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def start(
    hub,
    ctx,
    data_set_type: str,
    from_date: str,
    role_name_arn: str,
    destination_s3_bucket_name: str,
    sns_topic_arn: str,
    destination_s3_prefix: str = None,
    customer_defined_values: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Given a data set type and a from date, asynchronously publishes the requested customer support data to the specified S3 bucket and notifies the specified SNS topic once the data is available. Returns a unique request identifier that can be used to correlate requests with notifications from the SNS topic. Data sets will be published in comma-separated values (CSV) format with the file name {data_set_type}_YYYY-MM-DD'T'HH-mm-ss'Z'.csv. If a file with the same name already exists (e.g. if the same data set is requested twice), the original file will be overwritten by the new file. Requires a Role with an attached permissions policy providing Allow permissions for the following actions: s3:PutObject, s3:GetBucketLocation, sns:GetTopicAttributes, sns:Publish, iam:GetRolePolicy.

    Args:
        data_set_type(str):  Specifies the data set type to be written to the output csv file. The data set types customer_support_contacts_data and test_customer_support_contacts_data both result in a csv file containing the following fields: Product Id, Product Code, Customer Guid, Subscription Guid, Subscription Start Date, Organization, AWS Account Id, Given Name, Surname, Telephone Number, Email, Title, Country Code, ZIP Code, Operation Type, and Operation Time.    customer_support_contacts_data Customer support contact data. The data set will contain all changes (Creates, Updates, and Deletes) to customer support contact data from the date specified in the from_date parameter. test_customer_support_contacts_data An example data set containing static test data in the same format as customer_support_contacts_data  .
        from_date(str): The start date from which to retrieve the data set in UTC. This parameter only affects the customer_support_contacts_data data set type.
        role_name_arn(str): The Amazon Resource Name (ARN) of the Role with an attached permissions policy to interact with the provided AWS services.
        destination_s3_bucket_name(str): The name (friendly name, not ARN) of the destination S3 bucket.
        destination_s3_prefix(str, optional): (Optional) The desired S3 prefix for the published data set, similar to a directory path in standard file systems. For example, if given the bucket name "mybucket" and the prefix "myprefix/mydatasets", the output file "outputfile" would be published to "s3://mybucket/myprefix/mydatasets/outputfile". If the prefix directory structure does not exist, it will be created. If no prefix is provided, the data set will be published to the S3 bucket root. Defaults to None.
        sns_topic_arn(str): Amazon Resource Name (ARN) for the SNS Topic that will be notified when the data set has been published or if an error has occurred.
        customer_defined_values(Dict, optional): (Optional) Key-value pairs which will be returned, unmodified, in the Amazon SNS notification message and the data set metadata file. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.marketplacecommerceanalytic.support_data_export.start(
                ctx,
                data_set_type=value,
                from_date=value,
                role_name_arn=value,
                destination_s3_bucket_name=value,
                sns_topic_arn=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.marketplacecommerceanalytic.support_data_export.start data_set_type=value, from_date=value, role_name_arn=value, destination_s3_bucket_name=value, sns_topic_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="marketplacecommerceanalytics",
        operation="start_support_data_export",
        op_kwargs={
            "dataSetType": data_set_type,
            "fromDate": from_date,
            "roleNameArn": role_name_arn,
            "destinationS3BucketName": destination_s3_bucket_name,
            "destinationS3Prefix": destination_s3_prefix,
            "snsTopicArn": sns_topic_arn,
            "customerDefinedValues": customer_defined_values,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, configuration_set_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Create a new configuration set. After you create the configuration set, you can add one or more event destinations to it.

    Args:
        configuration_set_name(str, optional): The name that you want to give the configuration set. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_sms_voice.configuration_set_.init.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_sms_voice.configuration_set_.init.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-sms-voice",
        operation="create_configuration_set",
        op_kwargs={"ConfigurationSetName": configuration_set_name},
    )


async def delete(hub, ctx, configuration_set_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing configuration set.

    Args:
        configuration_set_name(str): ConfigurationSetName.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint_sms_voice.configuration_set_.init.delete(
                ctx, configuration_set_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint_sms_voice.configuration_set_.init.delete configuration_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint-sms-voice",
        operation="delete_configuration_set",
        op_kwargs={"ConfigurationSetName": configuration_set_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, security_policy_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the security policy that is attached to your file transfer protocol-enabled server. The response contains a description of the security policy's properties. For more information about security policies, see Working with security policies.

    Args:
        security_policy_name(str): Specifies the name of the security policy that is attached to the server.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transfer.security_policy.describe(
                ctx, security_policy_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transfer.security_policy.describe security_policy_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transfer",
        operation="describe_security_policy",
        op_kwargs={"SecurityPolicyName": security_policy_name},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the security policies that are attached to your file transfer protocol-enabled servers.

    Args:
        max_results(int, optional): Specifies the number of security policies to return as a response to the ListSecurityPolicies query. Defaults to None.
        next_token(str, optional): When additional results are obtained from the ListSecurityPolicies command, a NextToken parameter is returned in the output. You can then pass the NextToken parameter in a subsequent command to continue listing additional security policies. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.transfer.security_policy.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.transfer.security_policy.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="transfer",
        operation="list_security_policies",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def report(
    hub, ctx, taskrunner_id: str, worker_group: str = None, hostname: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Task runners call ReportTaskRunnerHeartbeat every 15 minutes to indicate that they are operational. If the AWS Data Pipeline Task Runner is launched on a resource managed by AWS Data Pipeline, the web service can use this call to detect when the task runner application has failed and restart a new instance.

    Args:
        taskrunner_id(str): The ID of the task runner. This value should be unique across your AWS account. In the case of AWS Data Pipeline Task Runner launched on a resource managed by AWS Data Pipeline, the web service provides a unique identifier when it launches the application. If you have written a custom task runner, you should assign a unique identifier for the task runner.
        worker_group(str, optional): The type of task the task runner is configured to accept and process. The worker group is set as a field on objects in the pipeline when they are created. You can only specify a single value for workerGroup. There are no wildcard values permitted in workerGroup; the string must be an exact, case-sensitive, match. Defaults to None.
        hostname(str, optional): The public DNS name of the task runner. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datapipeline.task.runner_heartbeat.report(
                ctx, taskrunner_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datapipeline.task.runner_heartbeat.report taskrunner_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datapipeline",
        operation="report_task_runner_heartbeat",
        op_kwargs={
            "taskrunnerId": taskrunner_id,
            "workerGroup": worker_group,
            "hostname": hostname,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, name: str, target_arns: List, description: str = None, tags: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a VPC link, under the caller's account in a selected region, in an asynchronous operation that typically takes 2-4 minutes to complete and become operational. The caller must have permissions to create and update VPC Endpoint services.

    Args:
        name(str): [Required] The name used to label and identify the VPC link.
        description(str, optional): The description of the VPC link. Defaults to None.
        target_arns(List): [Required] The ARN of the network load balancer of the VPC targeted by the VPC link. The network load balancer must be owned by the same AWS account of the API owner.
        tags(Dict, optional): The key-value map of strings. The valid character set is [a-zA-Z+-=._:/]. The tag key can be up to 128 characters and must not start with aws:. The tag value can be up to 256 characters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.vpc_link.create(ctx, name=value, target_arns=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.vpc_link.create name=value, target_arns=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="create_vpc_link",
        op_kwargs={
            "name": name,
            "description": description,
            "targetArns": target_arns,
            "tags": tags,
        },
    )


async def delete(hub, ctx, vpc_link_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an existing VpcLink of a specified identifier.

    Args:
        vpc_link_id(str): [Required] The identifier of the VpcLink. It is used in an Integration to reference this VpcLink.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.vpc_link.delete(ctx, vpc_link_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.vpc_link.delete vpc_link_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="delete_vpc_link",
        op_kwargs={"vpcLinkId": vpc_link_id},
    )


async def get(hub, ctx, vpc_link_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a specified VPC link under the caller's account in a region.

    Args:
        vpc_link_id(str): [Required] The identifier of the VpcLink. It is used in an Integration to reference this VpcLink.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.vpc_link.get(ctx, vpc_link_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.vpc_link.get vpc_link_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_vpc_link",
        op_kwargs={"vpcLinkId": vpc_link_id},
    )


async def get_all(hub, ctx, position: str = None, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Gets the VpcLinks collection under the caller's account in a selected region.

    Args:
        position(str, optional): The current pagination position in the paged result set. Defaults to None.
        limit(int, optional): The maximum number of returned results per page. The default value is 25 and the maximum value is 500. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.vpc_link.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.vpc_link.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="get_vpc_links",
        op_kwargs={"position": position, "limit": limit},
    )


async def update(hub, ctx, vpc_link_id: str, patch_operations: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing VpcLink of a specified identifier.

    Args:
        vpc_link_id(str): [Required] The identifier of the VpcLink. It is used in an Integration to reference this VpcLink.
        patch_operations(List, optional): A list of update operations to be applied to the specified resource and in the order specified in this list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigateway.vpc_link.update(ctx, vpc_link_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigateway.vpc_link.update vpc_link_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigateway",
        operation="update_vpc_link",
        op_kwargs={"vpcLinkId": vpc_link_id, "patchOperations": patch_operations},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, name: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns an array of journal export job descriptions for a specified ledger. This action returns a maximum of MaxResults items, and is paginated so that you can retrieve all the items by calling ListJournalS3ExportsForLedger multiple times. This action does not return any expired export jobs. For more information, see Export job expiration in the Amazon QLDB Developer Guide.

    Args:
        name(str): The name of the ledger.
        max_results(int, optional): The maximum number of results to return in a single ListJournalS3ExportsForLedger request. (The actual number of results returned might be fewer.). Defaults to None.
        next_token(str, optional): A pagination token, indicating that you want to retrieve the next page of results. If you received a value for NextToken in the response from a previous ListJournalS3ExportsForLedger call, then you should use that value as input here. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.qldb.journal.s3_export.for_ledger.list(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.qldb.journal.s3_export.for_ledger.list name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="qldb",
        operation="list_journal_s3_exports_for_ledger",
        op_kwargs={"Name": name, "MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def allocate(
    hub,
    ctx,
    connection_id: str,
    owner_account: str,
    bandwidth: str,
    connection_name: str,
    vlan: int,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a hosted connection on the specified interconnect or a link aggregation group (LAG) of interconnects. Allocates a VLAN number and a specified amount of capacity (bandwidth) for use by a hosted connection on the specified interconnect or LAG of interconnects. Amazon Web Services polices the hosted connection for the specified capacity and the Direct Connect Partner must also police the hosted connection for the specified capacity.  Intended for use by Direct Connect Partners only.

    Args:
        connection_id(str): The ID of the interconnect or LAG.
        owner_account(str): The ID of the account ID of the customer for the connection.
        bandwidth(str): The bandwidth of the connection. The possible values are 50Mbps, 100Mbps, 200Mbps, 300Mbps, 400Mbps, 500Mbps, 1Gbps, 2Gbps, 5Gbps, and 10Gbps. Note that only those Direct Connect Partners who have met specific requirements are allowed to create a 1Gbps, 2Gbps, 5Gbps or 10Gbps hosted connection. .
        connection_name(str): The name of the hosted connection.
        vlan(int): The dedicated VLAN provisioned to the hosted connection.
        tags(List, optional): The tags associated with the connection. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.hosted_connection.allocate(
                ctx,
                connection_id=value,
                owner_account=value,
                bandwidth=value,
                connection_name=value,
                vlan=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.hosted_connection.allocate connection_id=value, owner_account=value, bandwidth=value, connection_name=value, vlan=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="allocate_hosted_connection",
        op_kwargs={
            "connectionId": connection_id,
            "ownerAccount": owner_account,
            "bandwidth": bandwidth,
            "connectionName": connection_name,
            "vlan": vlan,
            "tags": tags,
        },
    )


async def associate(hub, ctx, connection_id: str, parent_connection_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Associates a hosted connection and its virtual interfaces with a link aggregation group (LAG) or interconnect. If the target interconnect or LAG has an existing hosted connection with a conflicting VLAN number or IP address, the operation fails. This action temporarily interrupts the hosted connection's connectivity to Amazon Web Services as it is being migrated.  Intended for use by Direct Connect Partners only.

    Args:
        connection_id(str): The ID of the hosted connection.
        parent_connection_id(str): The ID of the interconnect or the LAG.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.hosted_connection.associate(
                ctx, connection_id=value, parent_connection_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.hosted_connection.associate connection_id=value, parent_connection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="associate_hosted_connection",
        op_kwargs={
            "connectionId": connection_id,
            "parentConnectionId": parent_connection_id,
        },
    )


async def describe_all(hub, ctx, connection_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Lists the hosted connections that have been provisioned on the specified interconnect or link aggregation group (LAG).  Intended for use by Direct Connect Partners only.

    Args:
        connection_id(str): The ID of the interconnect or LAG.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.hosted_connection.describe_all(
                ctx, connection_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.hosted_connection.describe_all connection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="describe_hosted_connections",
        op_kwargs={"connectionId": connection_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete_multiple(hub, ctx, attributes: List, cluster: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes one or more custom attributes from an Amazon ECS resource.

    Args:
        cluster(str, optional): The short name or full Amazon Resource Name (ARN) of the cluster that contains the resource to delete attributes. If you do not specify a cluster, the default cluster is assumed. Defaults to None.
        attributes(List): The attributes to delete from your resource. You can specify up to 10 attributes per request. For custom attributes, specify the attribute name and target ID, but do not specify the value. If you specify the target ID using the short form, you must also specify the target type.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.attribute.delete_multiple(ctx, attributes=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.attribute.delete_multiple attributes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="delete_attributes",
        op_kwargs={"cluster": cluster, "attributes": attributes},
    )


async def list_all(
    hub,
    ctx,
    target_type: str,
    cluster: str = None,
    attribute_name: str = None,
    attribute_value: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the attributes for Amazon ECS resources within a specified target type and cluster. When you specify a target type and cluster, ListAttributes returns a list of attribute objects, one for each attribute on each resource. You can filter the list of results to a single attribute name to only return results that have that name. You can also filter the results by attribute name and value, for example, to see which container instances in a cluster are running a Linux AMI (ecs.os-type=linux).

    Args:
        cluster(str, optional): The short name or full Amazon Resource Name (ARN) of the cluster to list attributes. If you do not specify a cluster, the default cluster is assumed. Defaults to None.
        target_type(str): The type of the target with which to list attributes.
        attribute_name(str, optional): The name of the attribute with which to filter the results. . Defaults to None.
        attribute_value(str, optional): The value of the attribute with which to filter results. You must also specify an attribute name to use this parameter. Defaults to None.
        next_token(str, optional): The nextToken value returned from a ListAttributes request indicating that more results are available to fulfill the request and further calls will be needed. If maxResults was provided, it is possible the number of results to be fewer than maxResults.  This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.
        max_results(int, optional): The maximum number of cluster results returned by ListAttributes in paginated output. When this parameter is used, ListAttributes only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListAttributes request with the returned nextToken value. This value can be between 1 and 100. If this parameter is not used, then ListAttributes returns up to 100 results and a nextToken value if applicable. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.attribute.list_all(ctx, target_type=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.attribute.list_all target_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="list_attributes",
        op_kwargs={
            "cluster": cluster,
            "targetType": target_type,
            "attributeName": attribute_name,
            "attributeValue": attribute_value,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def put_multiple(hub, ctx, attributes: List, cluster: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Create or update an attribute on an Amazon ECS resource. If the attribute does not exist, it is created. If the attribute exists, its value is replaced with the specified value. To delete an attribute, use DeleteAttributes. For more information, see Attributes in the Amazon Elastic Container Service Developer Guide.

    Args:
        cluster(str, optional): The short name or full Amazon Resource Name (ARN) of the cluster that contains the resource to apply attributes. If you do not specify a cluster, the default cluster is assumed. Defaults to None.
        attributes(List): The attributes to apply to your resource. You can specify up to 10 custom attributes per resource. You can specify up to 10 attributes in a single call.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.attribute.put_multiple(ctx, attributes=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.attribute.put_multiple attributes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="put_attributes",
        op_kwargs={"cluster": cluster, "attributes": attributes},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    bgp_asn: int,
    type_: str,
    public_ip: str = None,
    certificate_arn: str = None,
    tag_specifications: List = None,
    device_name: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides information to AWS about your VPN customer gateway device. The customer gateway is the appliance at your end of the VPN connection. (The device on the AWS side of the VPN connection is the virtual private gateway.) You must provide the internet-routable IP address of the customer gateway's external interface. The IP address must be static and can be behind a device performing network address translation (NAT). For devices that use Border Gateway Protocol (BGP), you can also provide the device's BGP Autonomous System Number (ASN). You can use an existing ASN assigned to your network. If you don't have an ASN already, you can use a private ASN (in the 64512 - 65534 range).  Amazon EC2 supports all 4-byte ASN numbers in the range of 1 - 2147483647, with the exception of the following:   7224 - reserved in the us-east-1 Region   9059 - reserved in the eu-west-1 Region   17943 - reserved in the ap-southeast-1 Region   10124 - reserved in the ap-northeast-1 Region    For more information, see AWS Site-to-Site VPN in the AWS Site-to-Site VPN User Guide.  To create more than one customer gateway with the same VPN type, IP address, and BGP ASN, specify a unique device name for each customer gateway. Identical requests return information about the existing customer gateway and do not create new customer gateways.

    Args:
        bgp_asn(int): For devices that support BGP, the customer gateway's BGP ASN. Default: 65000.
        public_ip(str, optional): The Internet-routable IP address for the customer gateway's outside interface. The address must be static. Defaults to None.
        certificate_arn(str, optional): The Amazon Resource Name (ARN) for the customer gateway certificate. Defaults to None.
        type_(str): The type of VPN connection that this customer gateway supports (ipsec.1).
        tag_specifications(List, optional): The tags to apply to the customer gateway. Defaults to None.
        device_name(str, optional): A name for the customer gateway device. Length Constraints: Up to 255 characters. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.customer_gateway.create(ctx, bgp_asn=value, type_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.customer_gateway.create bgp_asn=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_customer_gateway",
        op_kwargs={
            "BgpAsn": bgp_asn,
            "PublicIp": public_ip,
            "CertificateArn": certificate_arn,
            "Type": type_,
            "TagSpecifications": tag_specifications,
            "DeviceName": device_name,
            "DryRun": dry_run,
        },
    )


async def delete(hub, ctx, customer_gateway_id: str, dry_run: bool = None) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified customer gateway. You must delete the VPN connection before you can delete the customer gateway.

    Args:
        customer_gateway_id(str): The ID of the customer gateway.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.customer_gateway.delete(ctx, customer_gateway_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.customer_gateway.delete customer_gateway_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_customer_gateway",
        op_kwargs={"CustomerGatewayId": customer_gateway_id, "DryRun": dry_run},
    )


async def describe_all(
    hub,
    ctx,
    customer_gateway_ids: List = None,
    filters: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your VPN customer gateways. For more information, see AWS Site-to-Site VPN in the AWS Site-to-Site VPN User Guide.

    Args:
        customer_gateway_ids(List, optional): One or more customer gateway IDs. Default: Describes all your customer gateways. Defaults to None.
        filters(List, optional): One or more filters.    bgp-asn - The customer gateway's Border Gateway Protocol (BGP) Autonomous System Number (ASN).    customer-gateway-id - The ID of the customer gateway.    ip-address - The IP address of the customer gateway's Internet-routable external interface.    state - The state of the customer gateway (pending | available | deleting | deleted).    type - The type of customer gateway. Currently, the only supported type is ipsec.1.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.customer_gateway.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.customer_gateway.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_customer_gateways",
        op_kwargs={
            "CustomerGatewayIds": customer_gateway_ids,
            "Filters": filters,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, max_jobs: int = None, marker: str = None, api_version: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    This operation returns the jobs associated with the requester. AWS Import/Export lists the jobs in reverse chronological order based on the date of creation. For example if Job Test1 was created 2009Dec30 and Test2 was created 2010Feb05, the ListJobs operation would return Test2 followed by Test1.

    Args:
        max_jobs(int, optional): Sets the maximum number of jobs returned in the response. If there are additional jobs that were not returned because MaxJobs was exceeded, the response contains <IsTruncated>true</IsTruncated>. To return the additional jobs, see Marker. Defaults to None.
        marker(str, optional): Specifies the JOBID to start after when listing the jobs created with your account. AWS Import/Export lists your jobs in reverse chronological order. See MaxJobs. Defaults to None.
        api_version(str, optional): Specifies the version of the client tool. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.importexport.jobs.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.importexport.jobs.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="importexport",
        operation="list_jobs",
        op_kwargs={"MaxJobs": max_jobs, "Marker": marker, "APIVersion": api_version},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    repository_name: str,
    registry_id: str = None,
    image_ids: List = None,
    next_token: str = None,
    max_results: int = None,
    filter_: Dict = None,
) -> Dict:
    r"""
       **Autogenerated function**

       Retrieves the results of the lifecycle policy preview request for the specified repository.

       Args:
           registry_id(str, optional): The AWS account ID associated with the registry that contains the repository. If you do not specify a registry, the default registry is assumed. Defaults to None.
           repository_name(str): The name of the repository.
           image_ids(List, optional): The list of imageIDs to be included. Defaults to None.
           next_token(str, optional): The nextToken value returned from a previous paginated
    GetLifecyclePolicyPreviewRequest request where maxResults was used and the
    results exceeded the value of that parameter. Pagination continues from the end of the
    previous results that returned the nextToken value. This value is
    null when there are no more results to return. This option cannot be used when you specify images with imageIds. Defaults to None.
           max_results(int, optional): The maximum number of repository results returned by GetLifecyclePolicyPreviewRequest in
    paginated output. When this parameter is used, GetLifecyclePolicyPreviewRequest only returns
    maxResults results in a single page along with a nextToken
    response element. The remaining results of the initial request can be seen by sending
    another GetLifecyclePolicyPreviewRequest request with the returned nextToken
    value. This value can be between 1 and 1000. If this
    parameter is not used, then GetLifecyclePolicyPreviewRequest returns up to
    100 results and a nextToken value, if
    applicable. This option cannot be used when you specify images with imageIds. Defaults to None.
           filter_(Dict, optional): An optional parameter that filters results based on image tag status and all tags, if tagged. Defaults to None.

       Returns:
           Dict

       Examples:
           Call from code:

           .. code-block:: python

               await hub.exec.aws_auto.ecr.lifecycle_policy.preview.get(ctx, repository_name=value)

           Call from CLI:

           .. code-block:: bash

               $ idem exec aws_auto.ecr.lifecycle_policy.preview.get repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="get_lifecycle_policy_preview",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "imageIds": image_ids,
            "nextToken": next_token,
            "maxResults": max_results,
            "filter": filter_,
        },
    )


async def start(
    hub,
    ctx,
    repository_name: str,
    registry_id: str = None,
    lifecycle_policy_text: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a preview of a lifecycle policy for the specified repository. This allows you to see the results before associating the lifecycle policy with the repository.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry that contains the repository. If you do not specify a registry, the default registry is assumed. Defaults to None.
        repository_name(str): The name of the repository to be evaluated.
        lifecycle_policy_text(str, optional): The policy to be evaluated against. If you do not specify a policy, the current policy for the repository is used. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr.lifecycle_policy.preview.start(ctx, repository_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr.lifecycle_policy.preview.start repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr",
        operation="start_lifecycle_policy_preview",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "lifecyclePolicyText": lifecycle_policy_text,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "set"


async def create(
    hub,
    ctx,
    service: str,
    cluster: str,
    task_definition: str,
    external_id: str = None,
    network_configuration: Dict = None,
    load_balancers: List = None,
    service_registries: List = None,
    launch_type: str = None,
    capacity_provider_strategy: List = None,
    platform_version: str = None,
    scale: Dict = None,
    client_token: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a task set in the specified cluster and service. This is used when a service uses the EXTERNAL deployment controller type. For more information, see Amazon ECS Deployment Types in the Amazon Elastic Container Service Developer Guide.

    Args:
        service(str): The short name or full Amazon Resource Name (ARN) of the service to create the task set in.
        cluster(str): The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service to create the task set in.
        external_id(str, optional): An optional non-unique tag that identifies this task set in external systems. If the task set is associated with a service discovery registry, the tasks in this task set will have the ECS_TASK_SET_EXTERNAL_ID Cloud Map attribute set to the provided value. Defaults to None.
        task_definition(str): The task definition for the tasks in the task set to use.
        network_configuration(Dict, optional): An object representing the network configuration for a task set. Defaults to None.
        load_balancers(List, optional): A load balancer object representing the load balancer to use with the task set. The supported load balancer types are either an Application Load Balancer or a Network Load Balancer. Defaults to None.
        service_registries(List, optional): The details of the service discovery registries to assign to this task set. For more information, see Service Discovery. Defaults to None.
        launch_type(str, optional): The launch type that new tasks in the task set will use. For more information, see Amazon ECS Launch Types in the Amazon Elastic Container Service Developer Guide. If a launchType is specified, the capacityProviderStrategy parameter must be omitted. Defaults to None.
        capacity_provider_strategy(List, optional): The capacity provider strategy to use for the task set. A capacity provider strategy consists of one or more capacity providers along with the base and weight to assign to them. A capacity provider must be associated with the cluster to be used in a capacity provider strategy. The PutClusterCapacityProviders API is used to associate a capacity provider with a cluster. Only capacity providers with an ACTIVE or UPDATING status can be used. If a capacityProviderStrategy is specified, the launchType parameter must be omitted. If no capacityProviderStrategy or launchType is specified, the defaultCapacityProviderStrategy for the cluster is used. If specifying a capacity provider that uses an Auto Scaling group, the capacity provider must already be created. New capacity providers can be created with the CreateCapacityProvider API operation. To use a Fargate capacity provider, specify either the FARGATE or FARGATE_SPOT capacity providers. The Fargate capacity providers are available to all accounts and only need to be associated with a cluster to be used. The PutClusterCapacityProviders API operation is used to update the list of available capacity providers for a cluster after the cluster is created. Defaults to None.
        platform_version(str, optional): The platform version that the tasks in the task set should use. A platform version is specified only for tasks using the Fargate launch type. If one isn't specified, the LATEST platform version is used by default. Defaults to None.
        scale(Dict, optional): A floating-point percentage of the desired number of tasks to place and keep running in the task set. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Up to 32 ASCII characters are allowed. Defaults to None.
        tags(List, optional): The metadata that you apply to the task set to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. When a service is deleted, the tags are deleted as well. The following basic restrictions apply to tags:   Maximum number of tags per resource - 50   For each resource, each tag key must be unique, and each tag key can have only one value.   Maximum key length - 128 Unicode characters in UTF-8   Maximum value length - 256 Unicode characters in UTF-8   If your tagging schema is used across multiple services and resources, remember that other services may have restrictions on allowed characters. Generally allowed characters are: letters, numbers, and spaces representable in UTF-8, and the following characters: + - = . _ : / @.   Tag keys and values are case-sensitive.   Do not use aws:, AWS:, or any upper or lowercase combination of such as a prefix for either keys or values as it is reserved for Amazon Web Services use. You cannot edit or delete tag keys or values with this prefix. Tags with this prefix do not count against your tags per resource limit.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.task.set_.create(
                ctx, service=value, cluster=value, task_definition=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.task.set.create service=value, cluster=value, task_definition=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="create_task_set",
        op_kwargs={
            "service": service,
            "cluster": cluster,
            "externalId": external_id,
            "taskDefinition": task_definition,
            "networkConfiguration": network_configuration,
            "loadBalancers": load_balancers,
            "serviceRegistries": service_registries,
            "launchType": launch_type,
            "capacityProviderStrategy": capacity_provider_strategy,
            "platformVersion": platform_version,
            "scale": scale,
            "clientToken": client_token,
            "tags": tags,
        },
    )


async def delete(
    hub, ctx, cluster: str, service: str, task_set: str, force: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specified task set within a service. This is used when a service uses the EXTERNAL deployment controller type. For more information, see Amazon ECS Deployment Types in the Amazon Elastic Container Service Developer Guide.

    Args:
        cluster(str): The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task set exists in to delete.
        service(str): The short name or full Amazon Resource Name (ARN) of the service that hosts the task set to delete.
        task_set(str): The task set ID or full Amazon Resource Name (ARN) of the task set to delete.
        force(bool, optional): If true, this allows you to delete a task set even if it hasn't been scaled down to zero. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.task.set_.delete(
                ctx, cluster=value, service=value, task_set=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.task.set.delete cluster=value, service=value, task_set=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="delete_task_set",
        op_kwargs={
            "cluster": cluster,
            "service": service,
            "taskSet": task_set,
            "force": force,
        },
    )


async def describe_all(
    hub, ctx, cluster: str, service: str, task_sets: List = None, include: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the task sets in the specified cluster and service. This is used when a service uses the EXTERNAL deployment controller type. For more information, see Amazon ECS Deployment Types in the Amazon Elastic Container Service Developer Guide.

    Args:
        cluster(str): The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task sets exist in.
        service(str): The short name or full Amazon Resource Name (ARN) of the service that the task sets exist in.
        task_sets(List, optional): The ID or full Amazon Resource Name (ARN) of task sets to describe. Defaults to None.
        include(List, optional): Specifies whether to see the resource tags for the task set. If TAGS is specified, the tags are included in the response. If this field is omitted, tags are not included in the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.task.set_.describe_all(ctx, cluster=value, service=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.task.set.describe_all cluster=value, service=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="describe_task_sets",
        op_kwargs={
            "cluster": cluster,
            "service": service,
            "taskSets": task_sets,
            "include": include,
        },
    )


async def update(
    hub, ctx, cluster: str, service: str, task_set: str, scale: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies a task set. This is used when a service uses the EXTERNAL deployment controller type. For more information, see Amazon ECS Deployment Types in the Amazon Elastic Container Service Developer Guide.

    Args:
        cluster(str): The short name or full Amazon Resource Name (ARN) of the cluster that hosts the service that the task set exists in.
        service(str): The short name or full Amazon Resource Name (ARN) of the service that the task set exists in.
        task_set(str): The short name or full Amazon Resource Name (ARN) of the task set to update.
        scale(Dict): A floating-point percentage of the desired number of tasks to place and keep running in the task set.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.task.set_.update(
                ctx, cluster=value, service=value, task_set=value, scale=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.task.set.update cluster=value, service=value, task_set=value, scale=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="update_task_set",
        op_kwargs={
            "cluster": cluster,
            "service": service,
            "taskSet": task_set,
            "scale": scale,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "slot_type"


async def get_all(
    hub,
    ctx,
    locale: str = None,
    signature_contains: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of built-in slot types that meet the specified criteria. For a list of built-in slot types, see Slot Type Reference in the Alexa Skills Kit. This operation requires permission for the lex:GetBuiltInSlotTypes action.

    Args:
        locale(str, optional): A list of locales that the slot type supports. Defaults to None.
        signature_contains(str, optional): Substring to match in built-in slot type signatures. A slot type will be returned if any part of its signature matches the substring. For example, "xyz" matches both "xyzabc" and "abcxyz.". Defaults to None.
        next_token(str, optional): A pagination token that fetches the next page of slot types. If the response to this API call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of slot types, specify the pagination token in the next request. Defaults to None.
        max_results(int, optional): The maximum number of slot types to return in the response. The default is 10. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.builtin.slot_type_.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.builtin.slot_type.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="get_builtin_slot_types",
        op_kwargs={
            "locale": locale,
            "signatureContains": signature_contains,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def add(
    hub,
    ctx,
    application_name: str,
    current_application_version_id: int,
    cloud_watch_logging_option: Dict,
) -> Dict:
    r"""
    **Autogenerated function**

     This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications. Version 2 of the API supports SQL and Java applications. For more information about version 2, see Amazon Kinesis Data Analytics API V2 Documentation.  Adds a CloudWatch log stream to monitor application configuration errors. For more information about using CloudWatch log streams with Amazon Kinesis Analytics applications, see Working with Amazon CloudWatch Logs.

    Args:
        application_name(str): The Kinesis Analytics application name.
        current_application_version_id(int): The version ID of the Kinesis Analytics application.
        cloud_watch_logging_option(Dict): Provides the CloudWatch log stream Amazon Resource Name (ARN) and the IAM role ARN. Note: To write application messages to CloudWatch, the IAM role that is used must have the PutLogEvents policy action enabled.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalytic.application.cloud_watch_logging_option.add(
                ctx,
                application_name=value,
                current_application_version_id=value,
                cloud_watch_logging_option=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalytic.application.cloud_watch_logging_option.add application_name=value, current_application_version_id=value, cloud_watch_logging_option=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalytics",
        operation="add_application_cloud_watch_logging_option",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
            "CloudWatchLoggingOption": cloud_watch_logging_option,
        },
    )


async def delete(
    hub,
    ctx,
    application_name: str,
    current_application_version_id: int,
    cloud_watch_logging_option_id: str,
) -> Dict:
    r"""
    **Autogenerated function**

     This documentation is for version 1 of the Amazon Kinesis Data Analytics API, which only supports SQL applications. Version 2 of the API supports SQL and Java applications. For more information about version 2, see Amazon Kinesis Data Analytics API V2 Documentation.  Deletes a CloudWatch log stream from an application. For more information about using CloudWatch log streams with Amazon Kinesis Analytics applications, see Working with Amazon CloudWatch Logs.

    Args:
        application_name(str): The Kinesis Analytics application name.
        current_application_version_id(int): The version ID of the Kinesis Analytics application.
        cloud_watch_logging_option_id(str): The CloudWatchLoggingOptionId of the CloudWatch logging option to delete. You can get the CloudWatchLoggingOptionId by using the DescribeApplication operation. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalytic.application.cloud_watch_logging_option.delete(
                ctx,
                application_name=value,
                current_application_version_id=value,
                cloud_watch_logging_option_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalytic.application.cloud_watch_logging_option.delete application_name=value, current_application_version_id=value, cloud_watch_logging_option_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalytics",
        operation="delete_application_cloud_watch_logging_option",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
            "CloudWatchLoggingOptionId": cloud_watch_logging_option_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    control_mapping_sources: List,
    description: str = None,
    testing_information: str = None,
    action_plan_title: str = None,
    action_plan_instructions: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a new custom control in Audit Manager.

    Args:
        name(str):  The name of the control. .
        description(str, optional):  The description of the control. . Defaults to None.
        testing_information(str, optional):  The steps to follow to determine if the control has been satisfied. . Defaults to None.
        action_plan_title(str, optional):  The title of the action plan for remediating the control. . Defaults to None.
        action_plan_instructions(str, optional):  The recommended actions to carry out if the control is not fulfilled. . Defaults to None.
        control_mapping_sources(List):  The data mapping sources for the specified control. .
        tags(Dict, optional):  The tags associated with the control. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.control.create(
                ctx, name=value, control_mapping_sources=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.control.create name=value, control_mapping_sources=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="create_control",
        op_kwargs={
            "name": name,
            "description": description,
            "testingInformation": testing_information,
            "actionPlanTitle": action_plan_title,
            "actionPlanInstructions": action_plan_instructions,
            "controlMappingSources": control_mapping_sources,
            "tags": tags,
        },
    )


async def delete(hub, ctx, control_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Deletes a custom control in Audit Manager.

    Args:
        control_id(str):  The identifier for the specified control. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.control.delete(ctx, control_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.control.delete control_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="delete_control",
        op_kwargs={"controlId": control_id},
    )


async def get(hub, ctx, control_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Returns a control from Audit Manager.

    Args:
        control_id(str):  The identifier for the specified control. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.control.get(ctx, control_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.control.get control_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="get_control",
        op_kwargs={"controlId": control_id},
    )


async def list_all(
    hub, ctx, control_type: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of controls from Audit Manager.

    Args:
        control_type(str):  The type of control, such as standard or custom. .
        next_token(str, optional):  The pagination token used to fetch the next set of results. . Defaults to None.
        max_results(int, optional):  Represents the maximum number of results per page, or per API request call. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.control.list_all(ctx, control_type=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.control.list_all control_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="list_controls",
        op_kwargs={
            "controlType": control_type,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    control_id: str,
    name: str,
    control_mapping_sources: List,
    description: str = None,
    testing_information: str = None,
    action_plan_title: str = None,
    action_plan_instructions: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Updates a custom control in Audit Manager.

    Args:
        control_id(str):  The identifier for the specified control. .
        name(str):  The name of the control to be updated. .
        description(str, optional):  The optional description of the control. . Defaults to None.
        testing_information(str, optional):  The steps that to follow to determine if the control has been satisfied. . Defaults to None.
        action_plan_title(str, optional):  The title of the action plan for remediating the control. . Defaults to None.
        action_plan_instructions(str, optional):  The recommended actions to carry out if the control is not fulfilled. . Defaults to None.
        control_mapping_sources(List):  The data mapping sources for the specified control. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.auditmanager.control.update(
                ctx, control_id=value, name=value, control_mapping_sources=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.auditmanager.control.update control_id=value, name=value, control_mapping_sources=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="auditmanager",
        operation="update_control",
        op_kwargs={
            "controlId": control_id,
            "name": name,
            "description": description,
            "testingInformation": testing_information,
            "actionPlanTitle": action_plan_title,
            "actionPlanInstructions": action_plan_instructions,
            "controlMappingSources": control_mapping_sources,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"import_": "import"}


async def bundle(
    hub, ctx, instance_id: str, storage: Dict, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Bundles an Amazon instance store-backed Windows instance. During bundling, only the root device volume (C:\) is bundled. Data on other instance store volumes is not preserved.  This action is not applicable for Linux/Unix instances or Windows instances that are backed by Amazon EBS.

    Args:
        instance_id(str): The ID of the instance to bundle. Type: String Default: None Required: Yes.
        storage(Dict): The bucket in which to store the AMI. You can specify a bucket that you already own or a new bucket that Amazon EC2 creates on your behalf. If you specify a bucket that belongs to someone else, Amazon EC2 returns an error.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.init.bundle(ctx, instance_id=value, storage=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.init.bundle instance_id=value, storage=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="bundle_instance",
        op_kwargs={"InstanceId": instance_id, "Storage": storage, "DryRun": dry_run},
    )


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    instance_ids: List = None,
    dry_run: bool = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified instances or all instances. If you specify instance IDs, the output includes information for only the specified instances. If you specify filters, the output includes information for only those instances that meet the filter criteria. If you do not specify instance IDs or filters, the output includes information for all instances, which can affect performance. We recommend that you use pagination to ensure that the operation returns quickly and successfully. If you specify an instance ID that is not valid, an error is returned. If you specify an instance that you do not own, it is not included in the output. Recently terminated instances might appear in the returned results. This interval is usually less than one hour. If you describe instances in the rare case where an Availability Zone is experiencing a service disruption and you specify instance IDs that are in the affected zone, or do not specify any instance IDs at all, the call fails. If you describe instances and specify only instance IDs that are in an unaffected zone, the call works normally.

    Args:
        filters(List, optional): The filters.    affinity - The affinity setting for an instance running on a Dedicated Host (default | host).    architecture - The instance architecture (i386 | x86_64 | arm64).    availability-zone - The Availability Zone of the instance.    block-device-mapping.attach-time - The attach time for an EBS volume mapped to the instance, for example, 2010-09-15T17:15:20.000Z.    block-device-mapping.delete-on-termination - A Boolean that indicates whether the EBS volume is deleted on instance termination.    block-device-mapping.device-name - The device name specified in the block device mapping (for example, /dev/sdh or xvdh).    block-device-mapping.status - The status for the EBS volume (attaching | attached | detaching | detached).    block-device-mapping.volume-id - The volume ID of the EBS volume.    client-token - The idempotency token you provided when you launched the instance.    dns-name - The public DNS name of the instance.    group-id - The ID of the security group for the instance. EC2-Classic only.    group-name - The name of the security group for the instance. EC2-Classic only.    hibernation-options.configured - A Boolean that indicates whether the instance is enabled for hibernation. A value of true means that the instance is enabled for hibernation.     host-id - The ID of the Dedicated Host on which the instance is running, if applicable.    hypervisor - The hypervisor type of the instance (ovm | xen). The value xen is used for both Xen and Nitro hypervisors.    iam-instance-profile.arn - The instance profile associated with the instance. Specified as an ARN.    image-id - The ID of the image used to launch the instance.    instance-id - The ID of the instance.    instance-lifecycle - Indicates whether this is a Spot Instance or a Scheduled Instance (spot | scheduled).    instance-state-code - The state of the instance, as a 16-bit unsigned integer. The high byte is used for internal purposes and should be ignored. The low byte is set based on the state represented. The valid values are: 0 (pending), 16 (running), 32 (shutting-down), 48 (terminated), 64 (stopping), and 80 (stopped).    instance-state-name - The state of the instance (pending | running | shutting-down | terminated | stopping | stopped).    instance-type - The type of instance (for example, t2.micro).    instance.group-id - The ID of the security group for the instance.     instance.group-name - The name of the security group for the instance.     ip-address - The public IPv4 address of the instance.    kernel-id - The kernel ID.    key-name - The name of the key pair used when the instance was launched.    launch-index - When launching multiple instances, this is the index for the instance in the launch group (for example, 0, 1, 2, and so on).     launch-time - The time when the instance was launched.    metadata-options.http-tokens - The metadata request authorization state (optional | required)    metadata-options.http-put-response-hop-limit - The http metadata request put response hop limit (integer, possible values 1 to 64)    metadata-options.http-endpoint - Enable or disable metadata access on http endpoint (enabled | disabled)    monitoring-state - Indicates whether detailed monitoring is enabled (disabled | enabled).    network-interface.addresses.private-ip-address - The private IPv4 address associated with the network interface.    network-interface.addresses.primary - Specifies whether the IPv4 address of the network interface is the primary private IPv4 address.    network-interface.addresses.association.public-ip - The ID of the association of an Elastic IP address (IPv4) with a network interface.    network-interface.addresses.association.ip-owner-id - The owner ID of the private IPv4 address associated with the network interface.    network-interface.association.public-ip - The address of the Elastic IP address (IPv4) bound to the network interface.    network-interface.association.ip-owner-id - The owner of the Elastic IP address (IPv4) associated with the network interface.    network-interface.association.allocation-id - The allocation ID returned when you allocated the Elastic IP address (IPv4) for your network interface.    network-interface.association.association-id - The association ID returned when the network interface was associated with an IPv4 address.    network-interface.attachment.attachment-id - The ID of the interface attachment.    network-interface.attachment.instance-id - The ID of the instance to which the network interface is attached.    network-interface.attachment.instance-owner-id - The owner ID of the instance to which the network interface is attached.    network-interface.attachment.device-index - The device index to which the network interface is attached.    network-interface.attachment.status - The status of the attachment (attaching | attached | detaching | detached).    network-interface.attachment.attach-time - The time that the network interface was attached to an instance.    network-interface.attachment.delete-on-termination - Specifies whether the attachment is deleted when an instance is terminated.    network-interface.availability-zone - The Availability Zone for the network interface.    network-interface.description - The description of the network interface.    network-interface.group-id - The ID of a security group associated with the network interface.    network-interface.group-name - The name of a security group associated with the network interface.    network-interface.ipv6-addresses.ipv6-address - The IPv6 address associated with the network interface.    network-interface.mac-address - The MAC address of the network interface.    network-interface.network-interface-id - The ID of the network interface.    network-interface.owner-id - The ID of the owner of the network interface.    network-interface.private-dns-name - The private DNS name of the network interface.    network-interface.requester-id - The requester ID for the network interface.    network-interface.requester-managed - Indicates whether the network interface is being managed by Amazon Web Services.    network-interface.status - The status of the network interface (available) | in-use).    network-interface.source-dest-check - Whether the network interface performs source/destination checking. A value of true means that checking is enabled, and false means that checking is disabled. The value must be false for the network interface to perform network address translation (NAT) in your VPC.    network-interface.subnet-id - The ID of the subnet for the network interface.    network-interface.vpc-id - The ID of the VPC for the network interface.    outpost-arn - The Amazon Resource Name (ARN) of the Outpost.    owner-id - The Amazon Web Services account ID of the instance owner.    placement-group-name - The name of the placement group for the instance.    placement-partition-number - The partition in which the instance is located.    platform - The platform. To list only Windows instances, use windows.    private-dns-name - The private IPv4 DNS name of the instance.    private-ip-address - The private IPv4 address of the instance.    product-code - The product code associated with the AMI used to launch the instance.    product-code.type - The type of product code (devpay | marketplace).    ramdisk-id - The RAM disk ID.    reason - The reason for the current state of the instance (for example, shows "User Initiated [date]" when you stop or terminate the instance). Similar to the state-reason-code filter.    requester-id - The ID of the entity that launched the instance on your behalf (for example, Amazon Web Services Management Console, Auto Scaling, and so on).    reservation-id - The ID of the instance's reservation. A reservation ID is created any time you launch an instance. A reservation ID has a one-to-one relationship with an instance launch request, but can be associated with more than one instance if you launch multiple instances using the same launch request. For example, if you launch one instance, you get one reservation ID. If you launch ten instances using the same launch request, you also get one reservation ID.    root-device-name - The device name of the root device volume (for example, /dev/sda1).    root-device-type - The type of the root device volume (ebs | instance-store).    source-dest-check - Indicates whether the instance performs source/destination checking. A value of true means that checking is enabled, and false means that checking is disabled. The value must be false for the instance to perform network address translation (NAT) in your VPC.     spot-instance-request-id - The ID of the Spot Instance request.    state-reason-code - The reason code for the state change.    state-reason-message - A message that describes the state change.    subnet-id - The ID of the subnet for the instance.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources that have a tag with a specific key, regardless of the tag value.    tenancy - The tenancy of an instance (dedicated | default | host).    virtualization-type - The virtualization type of the instance (paravirtual | hvm).    vpc-id - The ID of the VPC that the instance is running in.  . Defaults to None.
        instance_ids(List, optional): The instance IDs. Default: Describes all your instances. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. This value can be between 5 and 1000. You cannot specify this parameter and the instance IDs parameter in the same call. Defaults to None.
        next_token(str, optional): The token to request the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_instances",
        op_kwargs={
            "Filters": filters,
            "InstanceIds": instance_ids,
            "DryRun": dry_run,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def import_(
    hub,
    ctx,
    platform: str,
    description: str = None,
    disk_images: List = None,
    dry_run: bool = None,
    launch_specification: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an import instance task using metadata from the specified disk image. This API action supports only single-volume VMs. To import multi-volume VMs, use ImportImage instead. This API action is not supported by the AWS Command Line Interface (AWS CLI). For information about using the Amazon EC2 CLI, which is deprecated, see Importing a VM to Amazon EC2 in the Amazon EC2 CLI Reference PDF file. For information about the import manifest referenced by this API action, see VM Import Manifest.

    Args:
        description(str, optional): A description for the instance being imported. Defaults to None.
        disk_images(List, optional): The disk image. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        launch_specification(Dict, optional): The launch specification. Defaults to None.
        platform(str): The instance operating system.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.init.import(ctx, platform=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.init.import platform=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="import_instance",
        op_kwargs={
            "Description": description,
            "DiskImages": disk_images,
            "DryRun": dry_run,
            "LaunchSpecification": launch_specification,
            "Platform": platform,
        },
    )


async def monitor(hub, ctx, instance_ids: List, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Enables detailed monitoring for a running instance. Otherwise, basic monitoring is enabled. For more information, see Monitoring your instances and volumes in the Amazon EC2 User Guide. To disable detailed monitoring, see .

    Args:
        instance_ids(List): The IDs of the instances.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.init.monitor(ctx, instance_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.init.monitor instance_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="monitor_instances",
        op_kwargs={"InstanceIds": instance_ids, "DryRun": dry_run},
    )


async def reboot(hub, ctx, instance_ids: List, dry_run: bool = None) -> None:
    r"""
    **Autogenerated function**

    Requests a reboot of the specified instances. This operation is asynchronous; it only queues a request to reboot the specified instances. The operation succeeds if the instances are valid and belong to you. Requests to reboot terminated instances are ignored. If an instance does not cleanly shut down within a few minutes, Amazon EC2 performs a hard reboot. For more information about troubleshooting, see Getting console output and rebooting instances in the Amazon EC2 User Guide.

    Args:
        instance_ids(List): The instance IDs.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.init.reboot(ctx, instance_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.init.reboot instance_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="reboot_instances",
        op_kwargs={"InstanceIds": instance_ids, "DryRun": dry_run},
    )


async def run(
    hub,
    ctx,
    max_count: int,
    min_count: int,
    block_device_mappings: List = None,
    image_id: str = None,
    instance_type: str = None,
    ipv6_address_count: int = None,
    ipv6_addresses: List = None,
    kernel_id: str = None,
    key_name: str = None,
    monitoring: Dict = None,
    placement: Dict = None,
    ramdisk_id: str = None,
    security_group_ids: List = None,
    security_groups: List = None,
    subnet_id: str = None,
    user_data: str = None,
    additional_info: str = None,
    client_token: str = None,
    disable_api_termination: bool = None,
    dry_run: bool = None,
    ebs_optimized: bool = None,
    iam_instance_profile: Dict = None,
    instance_initiated_shutdown_behavior: str = None,
    network_interfaces: List = None,
    private_ip_address: str = None,
    elastic_gpu_specification: List = None,
    elastic_inference_accelerators: List = None,
    tag_specifications: List = None,
    launch_template: Dict = None,
    instance_market_options: Dict = None,
    credit_specification: Dict = None,
    cpu_options: Dict = None,
    capacity_reservation_specification: Dict = None,
    hibernation_options: Dict = None,
    license_specifications: List = None,
    metadata_options: Dict = None,
    enclave_options: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Launches the specified number of instances using an AMI for which you have permissions. You can specify a number of options, or leave the default options. The following rules apply:   [EC2-VPC] If you don't specify a subnet ID, we choose a default subnet from your default VPC for you. If you don't have a default VPC, you must specify a subnet ID in the request.   [EC2-Classic] If don't specify an Availability Zone, we choose one for you.   Some instance types must be launched into a VPC. If you do not have a default VPC, or if you do not specify a subnet ID, the request fails. For more information, see Instance types available only in a VPC.   [EC2-VPC] All instances have a network interface with a primary private IPv4 address. If you don't specify this address, we choose one from the IPv4 range of your subnet.   Not all instance types support IPv6 addresses. For more information, see Instance types.   If you don't specify a security group ID, we use the default security group. For more information, see Security groups.   If any of the AMIs have a product code attached for which the user has not subscribed, the request fails.   You can create a launch template, which is a resource that contains the parameters to launch an instance. When you launch an instance using RunInstances, you can specify the launch template instead of specifying the launch parameters. To ensure faster instance launches, break up large requests into smaller batches. For example, create five separate launch requests for 100 instances each instead of one launch request for 500 instances. An instance is ready for you to use when it's in the running state. You can check the state of your instance using DescribeInstances. You can tag instances and EBS volumes during launch, after launch, or both. For more information, see CreateTags and Tagging your Amazon EC2 resources. Linux instances have access to the public key of the key pair at boot. You can use this key to provide secure access to the instance. Amazon EC2 public images use this feature to provide secure access without passwords. For more information, see Key pairs. For troubleshooting, see What to do if an instance immediately terminates, and Troubleshooting connecting to your instance.

    Args:
        block_device_mappings(List, optional): The block device mapping entries. Defaults to None.
        image_id(str, optional): The ID of the AMI. An AMI ID is required to launch an instance and must be specified here or in a launch template. Defaults to None.
        instance_type(str, optional): The instance type. For more information, see Instance types in the Amazon EC2 User Guide. Default: m1.small . Defaults to None.
        ipv6_address_count(int, optional): [EC2-VPC] The number of IPv6 addresses to associate with the primary network interface. Amazon EC2 chooses the IPv6 addresses from the range of your subnet. You cannot specify this option and the option to assign specific IPv6 addresses in the same request. You can specify this option if you've specified a minimum number of instances to launch. You cannot specify this option and the network interfaces option in the same request. Defaults to None.
        ipv6_addresses(List, optional): [EC2-VPC] The IPv6 addresses from the range of the subnet to associate with the primary network interface. You cannot specify this option and the option to assign a number of IPv6 addresses in the same request. You cannot specify this option if you've specified a minimum number of instances to launch. You cannot specify this option and the network interfaces option in the same request. Defaults to None.
        kernel_id(str, optional): The ID of the kernel.  We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see  PV-GRUB in the Amazon EC2 User Guide. . Defaults to None.
        key_name(str, optional): The name of the key pair. You can create a key pair using CreateKeyPair or ImportKeyPair.  If you do not specify a key pair, you can't connect to the instance unless you choose an AMI that is configured to allow users another way to log in. . Defaults to None.
        max_count(int): The maximum number of instances to launch. If you specify more instances than Amazon EC2 can launch in the target Availability Zone, Amazon EC2 launches the largest possible number of instances above MinCount. Constraints: Between 1 and the maximum number you're allowed for the specified instance type. For more information about the default limits, and how to request an increase, see How many instances can I run in Amazon EC2 in the Amazon EC2 FAQ.
        min_count(int): The minimum number of instances to launch. If you specify a minimum that is more instances than Amazon EC2 can launch in the target Availability Zone, Amazon EC2 launches no instances. Constraints: Between 1 and the maximum number you're allowed for the specified instance type. For more information about the default limits, and how to request an increase, see How many instances can I run in Amazon EC2 in the Amazon EC2 General FAQ.
        monitoring(Dict, optional): Specifies whether detailed monitoring is enabled for the instance. Defaults to None.
        placement(Dict, optional): The placement for the instance. Defaults to None.
        ramdisk_id(str, optional): The ID of the RAM disk to select. Some kernels require additional drivers at launch. Check the kernel requirements for information about whether you need to specify a RAM disk. To find kernel requirements, go to the Amazon Web Services Resource Center and search for the kernel ID.  We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see  PV-GRUB in the Amazon EC2 User Guide. . Defaults to None.
        security_group_ids(List, optional): The IDs of the security groups. You can create a security group using CreateSecurityGroup. If you specify a network interface, you must specify any security groups as part of the network interface. Defaults to None.
        security_groups(List, optional): [EC2-Classic, default VPC] The names of the security groups. For a nondefault VPC, you must use security group IDs instead. If you specify a network interface, you must specify any security groups as part of the network interface. Default: Amazon EC2 uses the default security group. Defaults to None.
        subnet_id(str, optional): [EC2-VPC] The ID of the subnet to launch the instance into. If you specify a network interface, you must specify any subnets as part of the network interface. Defaults to None.
        user_data(str, optional): The user data to make available to the instance. For more information, see Running commands on your Linux instance at launch (Linux) and Adding User Data (Windows). If you are using a command line tool, base64-encoding is performed for you, and you can load the text from a file. Otherwise, you must provide base64-encoded text. User data is limited to 16 KB. Defaults to None.
        additional_info(str, optional): Reserved. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier you provide to ensure the idempotency of the request. If you do not specify a client token, a randomly generated token is used for the request to ensure idempotency. For more information, see Ensuring Idempotency. Constraints: Maximum 64 ASCII characters. Defaults to None.
        disable_api_termination(bool, optional): If you set this parameter to true, you can't terminate the instance using the Amazon EC2 console, CLI, or API; otherwise, you can. To change this attribute after launch, use ModifyInstanceAttribute. Alternatively, if you set InstanceInitiatedShutdownBehavior to terminate, you can terminate the instance by running the shutdown command from the instance. Default: false . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        ebs_optimized(bool, optional): Indicates whether the instance is optimized for Amazon EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal Amazon EBS I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS-optimized instance. Default: false . Defaults to None.
        iam_instance_profile(Dict, optional): The name or Amazon Resource Name (ARN) of an IAM instance profile. Defaults to None.
        instance_initiated_shutdown_behavior(str, optional): Indicates whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown). Default: stop . Defaults to None.
        network_interfaces(List, optional): The network interfaces to associate with the instance. If you specify a network interface, you must specify any security groups and subnets as part of the network interface. Defaults to None.
        private_ip_address(str, optional): [EC2-VPC] The primary IPv4 address. You must specify a value from the IPv4 address range of the subnet. Only one private IP address can be designated as primary. You can't specify this option if you've specified the option to designate a private IP address as the primary IP address in a network interface specification. You cannot specify this option if you're launching more than one instance in the request. You cannot specify this option and the network interfaces option in the same request. Defaults to None.
        elastic_gpu_specification(List, optional): An elastic GPU to associate with the instance. An Elastic GPU is a GPU resource that you can attach to your Windows instance to accelerate the graphics performance of your applications. For more information, see Amazon EC2 Elastic GPUs in the Amazon EC2 User Guide. Defaults to None.
        elastic_inference_accelerators(List, optional): An elastic inference accelerator to associate with the instance. Elastic inference accelerators are a resource you can attach to your Amazon EC2 instances to accelerate your Deep Learning (DL) inference workloads. You cannot specify accelerators from different generations in the same request. Defaults to None.
        tag_specifications(List, optional): The tags to apply to the resources during launch. You can only tag instances and volumes on launch. The specified tags are applied to all instances or volumes that are created during launch. To tag a resource after it has been created, see CreateTags. Defaults to None.
        launch_template(Dict, optional): The launch template to use to launch the instances. Any parameters that you specify in RunInstances override the same parameters in the launch template. You can specify either the name or ID of a launch template, but not both. Defaults to None.
        instance_market_options(Dict, optional): The market (purchasing) option for the instances. For RunInstances, persistent Spot Instance requests are only supported when InstanceInterruptionBehavior is set to either hibernate or stop. Defaults to None.
        credit_specification(Dict, optional): The credit option for CPU usage of the burstable performance instance. Valid values are standard and unlimited. To change this attribute after launch, use  ModifyInstanceCreditSpecification. For more information, see Burstable performance instances in the Amazon EC2 User Guide. Default: standard (T2 instances) or unlimited (T3/T3a instances). Defaults to None.
        cpu_options(Dict, optional): The CPU options for the instance. For more information, see Optimizing CPU options in the Amazon EC2 User Guide. Defaults to None.
        capacity_reservation_specification(Dict, optional): Information about the Capacity Reservation targeting option. If you do not specify this parameter, the instance's Capacity Reservation preference defaults to open, which enables it to run in any open Capacity Reservation that has matching attributes (instance type, platform, Availability Zone). Defaults to None.
        hibernation_options(Dict, optional): Indicates whether an instance is enabled for hibernation. For more information, see Hibernate your instance in the Amazon EC2 User Guide. You can't enable hibernation and Amazon Web Services Nitro Enclaves on the same instance. Defaults to None.
        license_specifications(List, optional): The license configurations. Defaults to None.
        metadata_options(Dict, optional): The metadata options for the instance. For more information, see Instance metadata and user data. Defaults to None.
        enclave_options(Dict, optional): Indicates whether the instance is enabled for Amazon Web Services Nitro Enclaves. For more information, see  What is Amazon Web Services Nitro Enclaves? in the Amazon Web Services Nitro Enclaves User Guide. You can't enable Amazon Web Services Nitro Enclaves and hibernation on the same instance. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.init.run(ctx, max_count=value, min_count=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.init.run max_count=value, min_count=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="run_instances",
        op_kwargs={
            "BlockDeviceMappings": block_device_mappings,
            "ImageId": image_id,
            "InstanceType": instance_type,
            "Ipv6AddressCount": ipv6_address_count,
            "Ipv6Addresses": ipv6_addresses,
            "KernelId": kernel_id,
            "KeyName": key_name,
            "MaxCount": max_count,
            "MinCount": min_count,
            "Monitoring": monitoring,
            "Placement": placement,
            "RamdiskId": ramdisk_id,
            "SecurityGroupIds": security_group_ids,
            "SecurityGroups": security_groups,
            "SubnetId": subnet_id,
            "UserData": user_data,
            "AdditionalInfo": additional_info,
            "ClientToken": client_token,
            "DisableApiTermination": disable_api_termination,
            "DryRun": dry_run,
            "EbsOptimized": ebs_optimized,
            "IamInstanceProfile": iam_instance_profile,
            "InstanceInitiatedShutdownBehavior": instance_initiated_shutdown_behavior,
            "NetworkInterfaces": network_interfaces,
            "PrivateIpAddress": private_ip_address,
            "ElasticGpuSpecification": elastic_gpu_specification,
            "ElasticInferenceAccelerators": elastic_inference_accelerators,
            "TagSpecifications": tag_specifications,
            "LaunchTemplate": launch_template,
            "InstanceMarketOptions": instance_market_options,
            "CreditSpecification": credit_specification,
            "CpuOptions": cpu_options,
            "CapacityReservationSpecification": capacity_reservation_specification,
            "HibernationOptions": hibernation_options,
            "LicenseSpecifications": license_specifications,
            "MetadataOptions": metadata_options,
            "EnclaveOptions": enclave_options,
        },
    )


async def start(
    hub, ctx, instance_ids: List, additional_info: str = None, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Starts an Amazon EBS-backed instance that you've previously stopped. Instances that use Amazon EBS volumes as their root devices can be quickly stopped and started. When an instance is stopped, the compute resources are released and you are not billed for instance usage. However, your root partition Amazon EBS volume remains and continues to persist your data, and you are charged for Amazon EBS volume usage. You can restart your instance at any time. Every time you start your instance, Amazon EC2 charges a one-minute minimum for instance usage, and thereafter charges per second for instance usage. Before stopping an instance, make sure it is in a state from which it can be restarted. Stopping an instance does not preserve data stored in RAM. Performing this operation on an instance that uses an instance store as its root device returns an error. For more information, see Stopping instances in the Amazon EC2 User Guide.

    Args:
        instance_ids(List): The IDs of the instances.
        additional_info(str, optional): Reserved. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.init.start(ctx, instance_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.init.start instance_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="start_instances",
        op_kwargs={
            "InstanceIds": instance_ids,
            "AdditionalInfo": additional_info,
            "DryRun": dry_run,
        },
    )


async def stop(
    hub,
    ctx,
    instance_ids: List,
    hibernate: bool = None,
    dry_run: bool = None,
    force: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Stops an Amazon EBS-backed instance. You can use the Stop action to hibernate an instance if the instance is enabled for hibernation and it meets the hibernation prerequisites. For more information, see Hibernate your instance in the Amazon EC2 User Guide. We don't charge usage for a stopped instance, or data transfer fees; however, your root partition Amazon EBS volume remains and continues to persist your data, and you are charged for Amazon EBS volume usage. Every time you start your instance, Amazon EC2 charges a one-minute minimum for instance usage, and thereafter charges per second for instance usage. You can't stop or hibernate instance store-backed instances. You can't use the Stop action to hibernate Spot Instances, but you can specify that Amazon EC2 should hibernate Spot Instances when they are interrupted. For more information, see Hibernating interrupted Spot Instances in the Amazon EC2 User Guide. When you stop or hibernate an instance, we shut it down. You can restart your instance at any time. Before stopping or hibernating an instance, make sure it is in a state from which it can be restarted. Stopping an instance does not preserve data stored in RAM, but hibernating an instance does preserve data stored in RAM. If an instance cannot hibernate successfully, a normal shutdown occurs. Stopping and hibernating an instance is different to rebooting or terminating it. For example, when you stop or hibernate an instance, the root device and any other devices attached to the instance persist. When you terminate an instance, the root device and any other devices attached during the instance launch are automatically deleted. For more information about the differences between rebooting, stopping, hibernating, and terminating instances, see Instance lifecycle in the Amazon EC2 User Guide. When you stop an instance, we attempt to shut it down forcibly after a short while. If your instance appears stuck in the stopping state after a period of time, there may be an issue with the underlying host computer. For more information, see Troubleshooting stopping your instance in the Amazon EC2 User Guide.

    Args:
        instance_ids(List): The IDs of the instances.
        hibernate(bool, optional): Hibernates the instance if the instance was enabled for hibernation at launch. If the instance cannot hibernate successfully, a normal shutdown occurs. For more information, see Hibernate your instance in the Amazon EC2 User Guide.  Default: false . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        force(bool, optional): Forces the instances to stop. The instances do not have an opportunity to flush file system caches or file system metadata. If you use this option, you must perform file system check and repair procedures. This option is not recommended for Windows instances. Default: false . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.init.stop(ctx, instance_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.init.stop instance_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="stop_instances",
        op_kwargs={
            "InstanceIds": instance_ids,
            "Hibernate": hibernate,
            "DryRun": dry_run,
            "Force": force,
        },
    )


async def terminate(hub, ctx, instance_ids: List, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Shuts down the specified instances. This operation is idempotent; if you terminate an instance more than once, each call succeeds.  If you specify multiple instances and the request fails (for example, because of a single incorrect instance ID), none of the instances are terminated. If you terminate multiple instances across multiple Availability Zones, and one or more of the specified instances are enabled for termination protection, the request fails with the following results:   The specified instances that are in the same Availability Zone as the protected instance are not terminated.   The specified instances that are in different Availability Zones, where no other specified instances are protected, are successfully terminated.   For example, say you have the following instances:   Instance A: us-east-1a; Not protected   Instance B: us-east-1a; Not protected   Instance C: us-east-1b; Protected   Instance D: us-east-1b; not protected   If you attempt to terminate all of these instances in the same request, the request reports failure with the following results:   Instance A and Instance B are successfully terminated because none of the specified instances in us-east-1a are enabled for termination protection.   Instance C and Instance D fail to terminate because at least one of the specified instances in us-east-1b (Instance C) is enabled for termination protection.   Terminated instances remain visible after termination (for approximately one hour). By default, Amazon EC2 deletes all EBS volumes that were attached when the instance launched. Volumes attached after instance launch continue running. You can stop, start, and terminate EBS-backed instances. You can only terminate instance store-backed instances. What happens to an instance differs if you stop it or terminate it. For example, when you stop an instance, the root device and any other devices attached to the instance persist. When you terminate an instance, any attached EBS volumes with the DeleteOnTermination block device mapping parameter set to true are automatically deleted. For more information about the differences between stopping and terminating instances, see Instance lifecycle in the Amazon EC2 User Guide. For more information about troubleshooting, see Troubleshooting terminating your instance in the Amazon EC2 User Guide.

    Args:
        instance_ids(List): The IDs of the instances. Constraints: Up to 1000 instance IDs. We recommend breaking up this request into smaller batches.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.init.terminate(ctx, instance_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.init.terminate instance_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="terminate_instances",
        op_kwargs={"InstanceIds": instance_ids, "DryRun": dry_run},
    )


async def unmonitor(hub, ctx, instance_ids: List, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Disables detailed monitoring for a running instance. For more information, see Monitoring your instances and volumes in the Amazon EC2 User Guide.

    Args:
        instance_ids(List): The IDs of the instances.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.init.unmonitor(ctx, instance_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.init.unmonitor instance_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="unmonitor_instances",
        op_kwargs={"InstanceIds": instance_ids, "DryRun": dry_run},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    broker_node_group_info: Dict,
    cluster_name: str,
    kafka_version: str,
    number_of_broker_nodes: int,
    client_authentication: Dict = None,
    configuration_info: Dict = None,
    encryption_info: Dict = None,
    enhanced_monitoring: str = None,
    open_monitoring: Dict = None,
    logging_info: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
        **Autogenerated function**


        Creates a new MSK cluster.


        Args:
            broker_node_group_info(Dict):
    Information about the broker nodes in the cluster.
    .
            client_authentication(Dict, optional):
    Includes all client authentication related information.
    . Defaults to None.
            cluster_name(str):
    The name of the cluster.
    .
            configuration_info(Dict, optional):
    Represents the configuration that you want MSK to use for the brokers in a cluster.
    . Defaults to None.
            encryption_info(Dict, optional):
    Includes all encryption-related information.
    . Defaults to None.
            enhanced_monitoring(str, optional):
    Specifies the level of monitoring for the MSK cluster. The possible values are DEFAULT, PER_BROKER, PER_TOPIC_PER_BROKER, and PER_TOPIC_PER_PARTITION.
    . Defaults to None.
            open_monitoring(Dict, optional):
    The settings for open monitoring.
    . Defaults to None.
            kafka_version(str):
    The version of Apache Kafka.
    .
            logging_info(Dict, optional): . Defaults to None.
            number_of_broker_nodes(int):
    The number of broker nodes in the cluster.
    .
            tags(Dict, optional):
    Create tags when creating the cluster.
    . Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.cluster.init.create(
                    ctx,
                    broker_node_group_info=value,
                    cluster_name=value,
                    kafka_version=value,
                    number_of_broker_nodes=value,
                )

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.cluster.init.create broker_node_group_info=value, cluster_name=value, kafka_version=value, number_of_broker_nodes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="create_cluster",
        op_kwargs={
            "BrokerNodeGroupInfo": broker_node_group_info,
            "ClientAuthentication": client_authentication,
            "ClusterName": cluster_name,
            "ConfigurationInfo": configuration_info,
            "EncryptionInfo": encryption_info,
            "EnhancedMonitoring": enhanced_monitoring,
            "OpenMonitoring": open_monitoring,
            "KafkaVersion": kafka_version,
            "LoggingInfo": logging_info,
            "NumberOfBrokerNodes": number_of_broker_nodes,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, cluster_arn: str, current_version: str = None) -> Dict:
    r"""
        **Autogenerated function**


        Deletes the MSK cluster specified by the Amazon Resource Name (ARN) in the request.


        Args:
            cluster_arn(str):
    The Amazon Resource Name (ARN) that uniquely identifies the cluster.
    .
            current_version(str, optional):
    The current version of the MSK cluster.
    . Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.cluster.init.delete(ctx, cluster_arn=value)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.cluster.init.delete cluster_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="delete_cluster",
        op_kwargs={"ClusterArn": cluster_arn, "CurrentVersion": current_version},
    )


async def describe(hub, ctx, cluster_arn: str) -> Dict:
    r"""
        **Autogenerated function**


        Returns a description of the MSK cluster whose Amazon Resource Name (ARN) is specified in the request.


        Args:
            cluster_arn(str):
    The Amazon Resource Name (ARN) that uniquely identifies the cluster.
    .

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.cluster.init.describe(ctx, cluster_arn=value)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.cluster.init.describe cluster_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="describe_cluster",
        op_kwargs={"ClusterArn": cluster_arn},
    )


async def list_all(
    hub,
    ctx,
    cluster_name_filter: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
        **Autogenerated function**


        Returns a list of all the MSK clusters in the current Region.


        Args:
            cluster_name_filter(str, optional):
    Specify a prefix of the name of the clusters that you want to list. The service lists all the clusters whose names start with this prefix.
    . Defaults to None.
            max_results(int, optional):
    The maximum number of results to return in the response. If there are more results, the response includes a NextToken parameter.
    . Defaults to None.
            next_token(str, optional):
    The paginated results marker. When the result of the operation is truncated, the call returns NextToken in the response.
                To get the next batch, provide this token in your next request.
    . Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.cluster.init.list_all(ctx)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.cluster.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="list_clusters",
        op_kwargs={
            "ClusterNameFilter": cluster_name_filter,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, arn: str, tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Adds tags to a resource group with the specified ARN. Existing tags on a resource group are not changed if they are not specified in the request parameters.  Do not store personally identifiable information (PII) or other confidential or sensitive information in tags. We use tags to provide you with billing and administration services. Tags are not intended to be used for private or sensitive data.   Minimum permissions  To run this command, you must have the following permissions:    resource-groups:Tag

    Args:
        arn(str): The ARN of the resource group to which to add tags.
        tags(Dict): The tags to add to the specified resource group. A tag is a string-to-string map of key-value pairs.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.resource_group.init.tag(ctx, arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.resource_group.init.tag arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="resource-groups",
        operation="tag",
        op_kwargs={"Arn": arn, "Tags": tags},
    )


async def untag(hub, ctx, arn: str, keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes tags from a specified resource group.  Minimum permissions  To run this command, you must have the following permissions:    resource-groups:Untag

    Args:
        arn(str): The ARN of the resource group from which to remove tags. The command removed both the specified keys and any values associated with those keys.
        keys(List): The keys of the tags to be removed.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.resource_group.init.untag(ctx, arn=value, keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.resource_group.init.untag arn=value, keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="resource-groups",
        operation="untag",
        op_kwargs={"Arn": arn, "Keys": keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    client_token: str,
    profiling_group_name: str,
    agent_orchestration_config: Dict = None,
    compute_platform: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a profiling group.

    Args:
        agent_orchestration_config(Dict, optional):  Specifies whether profiling is enabled or disabled for the created profiling group. . Defaults to None.
        client_token(str):  Amazon CodeGuru Profiler uses this universally unique identifier (UUID) to prevent the accidental creation of duplicate profiling groups if there are failures and retries. .
        compute_platform(str, optional):  The compute platform of the profiling group. Use AWSLambda if your application runs on AWS Lambda. Use Default if your application runs on a compute platform that is not AWS Lambda, such an Amazon EC2 instance, an on-premises server, or a different platform. If not specified, Default is used. . Defaults to None.
        profiling_group_name(str): The name of the profiling group to create.
        tags(Dict, optional):  A list of tags to add to the created profiling group. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguruprofiler.profiling_group.create(
                ctx, client_token=value, profiling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguruprofiler.profiling_group.create client_token=value, profiling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguruprofiler",
        operation="create_profiling_group",
        op_kwargs={
            "agentOrchestrationConfig": agent_orchestration_config,
            "clientToken": client_token,
            "computePlatform": compute_platform,
            "profilingGroupName": profiling_group_name,
            "tags": tags,
        },
    )


async def delete(hub, ctx, profiling_group_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a profiling group.

    Args:
        profiling_group_name(str): The name of the profiling group to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguruprofiler.profiling_group.delete(
                ctx, profiling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguruprofiler.profiling_group.delete profiling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguruprofiler",
        operation="delete_profiling_group",
        op_kwargs={"profilingGroupName": profiling_group_name},
    )


async def describe(hub, ctx, profiling_group_name: str) -> Dict:
    r"""
    **Autogenerated function**

     Returns a  ProfilingGroupDescription  object that contains information about the requested profiling group.

    Args:
        profiling_group_name(str):  The name of the profiling group to get information about. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguruprofiler.profiling_group.describe(
                ctx, profiling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguruprofiler.profiling_group.describe profiling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguruprofiler",
        operation="describe_profiling_group",
        op_kwargs={"profilingGroupName": profiling_group_name},
    )


async def list_all(
    hub,
    ctx,
    include_description: bool = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of profiling groups. The profiling groups are returned as  ProfilingGroupDescription  objects.

    Args:
        include_description(bool, optional): A Boolean value indicating whether to include a description. If true, then a list of  ProfilingGroupDescription  objects that contain detailed information about profiling groups is returned. If false, then a list of profiling group names is returned. Defaults to None.
        max_results(int, optional): The maximum number of profiling groups results returned by ListProfilingGroups in paginated output. When this parameter is used, ListProfilingGroups only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another ListProfilingGroups request with the returned nextToken value. . Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated ListProfilingGroups request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value.   This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguruprofiler.profiling_group.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguruprofiler.profiling_group.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguruprofiler",
        operation="list_profiling_groups",
        op_kwargs={
            "includeDescription": include_description,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def update(
    hub, ctx, agent_orchestration_config: Dict, profiling_group_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a profiling group.

    Args:
        agent_orchestration_config(Dict):  Specifies whether profiling is enabled or disabled for a profiling group. .
        profiling_group_name(str): The name of the profiling group to update.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguruprofiler.profiling_group.update(
                ctx, agent_orchestration_config=value, profiling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguruprofiler.profiling_group.update agent_orchestration_config=value, profiling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguruprofiler",
        operation="update_profiling_group",
        op_kwargs={
            "agentOrchestrationConfig": agent_orchestration_config,
            "profilingGroupName": profiling_group_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def authorize(hub, ctx, group_id: str, user_rules: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds one or more rules to the specified IP access control group. This action gives users permission to access their WorkSpaces from the CIDR address ranges specified in the rules.

    Args:
        group_id(str): The identifier of the group.
        user_rules(List): The rules to add to the group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.ip.rule.authorize(
                ctx, group_id=value, user_rules=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.ip.rule.authorize group_id=value, user_rules=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="authorize_ip_rules",
        op_kwargs={"GroupId": group_id, "UserRules": user_rules},
    )


async def revoke(hub, ctx, group_id: str, user_rules: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes one or more rules from the specified IP access control group.

    Args:
        group_id(str): The identifier of the group.
        user_rules(List): The rules to remove from the group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.ip.rule.revoke(ctx, group_id=value, user_rules=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.ip.rule.revoke group_id=value, user_rules=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="revoke_ip_rules",
        op_kwargs={"GroupId": group_id, "UserRules": user_rules},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, layer_name: str, version_number: int) -> Dict:
    r"""
    **Autogenerated function**

    Returns the permission policy for a version of an Lambda layer. For more information, see AddLayerVersionPermission.

    Args:
        layer_name(str): The name or Amazon Resource Name (ARN) of the layer.
        version_number(int): The version number.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.layer.version.policy.get(
                ctx, layer_name=value, version_number=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.layer.version.policy.get layer_name=value, version_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="get_layer_version_policy",
        op_kwargs={"LayerName": layer_name, "VersionNumber": version_number},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    parameter_group_name: str,
    source: str = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a detailed list of parameters contained within the specified Amazon Redshift parameter group. For each parameter the response includes information such as parameter name, description, data type, value, whether the parameter value is modifiable, and so on. You can specify source filter to retrieve parameters of only specific type. For example, to retrieve parameters that were modified by a user action such as from ModifyClusterParameterGroup, you can specify source equal to user.  For more information about parameters and parameter groups, go to Amazon Redshift Parameter Groups in the Amazon Redshift Cluster Management Guide.

    Args:
        parameter_group_name(str): The name of a cluster parameter group for which to return details.
        source(str, optional): The parameter types to return. Specify user to show parameters that are different form the default. Similarly, specify engine-default to show parameters that are the same as the default parameter group.  Default: All parameter types returned. Valid Values: user | engine-default . Defaults to None.
        max_records(int, optional): The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.  Default: 100  Constraints: minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeClusterParameters request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.cluster.parameter.init.describe_all(
                ctx, parameter_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.cluster.parameter.init.describe_all parameter_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_cluster_parameters",
        op_kwargs={
            "ParameterGroupName": parameter_group_name,
            "Source": source,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about IAM entity usage and IAM quotas in the Amazon Web Services account.  For information about IAM quotas, see IAM and STS quotas in the IAM User Guide.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.account.summary.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.account.summary.get
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="iam", operation="get_account_summary", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "list"


async def create(
    hub,
    ctx,
    contact_list_name: str,
    topics: List = None,
    description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a contact list.

    Args:
        contact_list_name(str): The name of the contact list.
        topics(List, optional): An interest group, theme, or label within a list. A contact list can have multiple topics. Defaults to None.
        description(str, optional): A description of what the contact list is about. Defaults to None.
        tags(List, optional): The tags associated with a contact list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.contact.list_.create(ctx, contact_list_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.contact.list.create contact_list_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="create_contact_list",
        op_kwargs={
            "ContactListName": contact_list_name,
            "Topics": topics,
            "Description": description,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, contact_list_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a contact list and all of the contacts on that list.

    Args:
        contact_list_name(str): The name of the contact list.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.contact.list_.delete(ctx, contact_list_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.contact.list.delete contact_list_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="delete_contact_list",
        op_kwargs={"ContactListName": contact_list_name},
    )


async def get(hub, ctx, contact_list_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns contact list metadata. It does not return any information about the contacts present in the list.

    Args:
        contact_list_name(str): The name of the contact list.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.contact.list_.get(ctx, contact_list_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.contact.list.get contact_list_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="get_contact_list",
        op_kwargs={"ContactListName": contact_list_name},
    )


async def list_all(hub, ctx, page_size: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all of the contact lists available.

    Args:
        page_size(int, optional): Maximum number of contact lists to return at once. Use this parameter to paginate results. If additional contact lists exist beyond the specified limit, the NextToken element is sent in the response. Use the NextToken value in subsequent requests to retrieve additional lists. Defaults to None.
        next_token(str, optional): A string token indicating that there might be additional contact lists available to be listed. Use the token provided in the Response to use in the subsequent call to ListContactLists with the same parameters to retrieve the next page of contact lists. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.contact.list_.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.contact.list.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="list_contact_lists",
        op_kwargs={"PageSize": page_size, "NextToken": next_token},
    )


async def update(
    hub, ctx, contact_list_name: str, topics: List = None, description: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates contact list metadata. This operation does a complete replacement.

    Args:
        contact_list_name(str): The name of the contact list.
        topics(List, optional): An interest group, theme, or label within a list. A contact list can have multiple topics. Defaults to None.
        description(str, optional): A description of what the contact list is about. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sesv2.contact.list_.update(ctx, contact_list_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sesv2.contact.list.update contact_list_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sesv2",
        operation="update_contact_list",
        op_kwargs={
            "ContactListName": contact_list_name,
            "Topics": topics,
            "Description": description,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> None:
    r"""
    **Autogenerated function**

    This implementation of the DELETE action uses the policy subresource to delete the policy of a specified bucket. If you are using an identity other than the root user of the AWS account that owns the bucket, the calling identity must have the DeleteBucketPolicy permissions on the specified bucket and belong to the bucket owner's account to use this operation.  If you don't have DeleteBucketPolicy permissions, Amazon S3 returns a 403 Access Denied error. If you have the correct permissions, but you're not using an identity that belongs to the bucket owner's account, Amazon S3 returns a 405 Method Not Allowed error.   As a security precaution, the root user of the AWS account that owns a bucket can always use this operation, even if the policy explicitly denies the root user the ability to perform this action.  For more information about bucket policies, see Using Bucket Policies and UserPolicies.  The following operations are related to DeleteBucketPolicy     CreateBucket     DeleteObject

    Args:
        bucket(str): The bucket name.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.policy.init.delete(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.policy.init.delete bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="delete_bucket_policy",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def get(hub, ctx, bucket: str, expected_bucket_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the policy of a specified bucket. If you are using an identity other than the root user of the AWS account that owns the bucket, the calling identity must have the GetBucketPolicy permissions on the specified bucket and belong to the bucket owner's account in order to use this operation. If you don't have GetBucketPolicy permissions, Amazon S3 returns a 403 Access Denied error. If you have the correct permissions, but you're not using an identity that belongs to the bucket owner's account, Amazon S3 returns a 405 Method Not Allowed error.  As a security precaution, the root user of the AWS account that owns a bucket can always use this operation, even if the policy explicitly denies the root user the ability to perform this action.  For more information about bucket policies, see Using Bucket Policies and User Policies. The following action is related to GetBucketPolicy:    GetObject

    Args:
        bucket(str): The bucket name for which to get the bucket policy.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.policy.init.get(ctx, bucket=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.policy.init.get bucket=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="get_bucket_policy",
        op_kwargs={"Bucket": bucket, "ExpectedBucketOwner": expected_bucket_owner},
    )


async def put(
    hub,
    ctx,
    bucket: str,
    policy: str,
    content_md5: str = None,
    confirm_remove_self_bucket_access: bool = None,
    expected_bucket_owner: str = None,
) -> None:
    r"""
    **Autogenerated function**

    Applies an Amazon S3 bucket policy to an Amazon S3 bucket. If you are using an identity other than the root user of the AWS account that owns the bucket, the calling identity must have the PutBucketPolicy permissions on the specified bucket and belong to the bucket owner's account in order to use this operation. If you don't have PutBucketPolicy permissions, Amazon S3 returns a 403 Access Denied error. If you have the correct permissions, but you're not using an identity that belongs to the bucket owner's account, Amazon S3 returns a 405 Method Not Allowed error.   As a security precaution, the root user of the AWS account that owns a bucket can always use this operation, even if the policy explicitly denies the root user the ability to perform this action.   For more information about bucket policies, see Using Bucket Policies and User Policies. The following operations are related to PutBucketPolicy:    CreateBucket     DeleteBucket

    Args:
        bucket(str): The name of the bucket.
        content_md5(str, optional): The MD5 hash of the request body. For requests made using the AWS Command Line Interface (CLI) or AWS SDKs, this field is calculated automatically. Defaults to None.
        confirm_remove_self_bucket_access(bool, optional): Set this parameter to true to confirm that you want to remove your permissions to change this bucket policy in the future. Defaults to None.
        policy(str): The bucket policy as a JSON document.
        expected_bucket_owner(str, optional): The account ID of the expected bucket owner. If the bucket is owned by a different account, the request will fail with an HTTP 403 (Access Denied) error. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3.bucket.policy.init.put(ctx, bucket=value, policy=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3.bucket.policy.init.put bucket=value, policy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3",
        operation="put_bucket_policy",
        op_kwargs={
            "Bucket": bucket,
            "ContentMD5": content_md5,
            "ConfirmRemoveSelfBucketAccess": confirm_remove_self_bucket_access,
            "Policy": policy,
            "ExpectedBucketOwner": expected_bucket_owner,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub,
    ctx,
    domain: str,
    repository: str,
    external_connection: str,
    domain_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds an existing external connection to a repository. One external connection is allowed per repository.  A repository can have one or more upstream repositories, or an external connection.

    Args:
        domain(str): The name of the domain that contains the repository.
        domain_owner(str, optional):  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. . Defaults to None.
        repository(str):  The name of the repository to which the external connection is added. .
        external_connection(str):  The name of the external connection to add to the repository. The following values are supported:     public:npmjs - for the npm public repository.     public:pypi - for the Python Package Index.     public:maven-central - for Maven Central.     public:maven-googleandroid - for the Google Android repository.     public:maven-gradleplugins - for the Gradle plugins repository.     public:maven-commonsware - for the CommonsWare Android repository.   .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeartifact.external_connection.associate(
                ctx, domain=value, repository=value, external_connection=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeartifact.external_connection.associate domain=value, repository=value, external_connection=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeartifact",
        operation="associate_external_connection",
        op_kwargs={
            "domain": domain,
            "domainOwner": domain_owner,
            "repository": repository,
            "externalConnection": external_connection,
        },
    )


async def disassociate(
    hub,
    ctx,
    domain: str,
    repository: str,
    external_connection: str,
    domain_owner: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Removes an existing external connection from a repository.

    Args:
        domain(str): The name of the domain that contains the repository from which to remove the external repository. .
        domain_owner(str, optional):  The 12-digit account number of the AWS account that owns the domain. It does not include dashes or spaces. . Defaults to None.
        repository(str): The name of the repository from which the external connection will be removed. .
        external_connection(str): The name of the external connection to be removed from the repository. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeartifact.external_connection.disassociate(
                ctx, domain=value, repository=value, external_connection=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeartifact.external_connection.disassociate domain=value, repository=value, external_connection=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeartifact",
        operation="disassociate_external_connection",
        op_kwargs={
            "domain": domain,
            "domainOwner": domain_owner,
            "repository": repository,
            "externalConnection": external_connection,
        },
    )
